@@ -20,7 +20,7 @@ import re
 import shutil
 import tempfile
 
-version = "0.4.3"
+version = "0.5.0"
 
 re_options = re.IGNORECASE | re.MULTILINE | re.DOTALL
 skip_pattern = re.compile('# hghooks: (.*)', re_options)
@@ -28,14 +28,15 @@ skip_pattern = re.compile('# hghooks: (.*)', re_options)
 
 class CheckerManager(object):
 
-    def __init__(self, ui, repo, node, skip_text=None):
+    def __init__(self, ui, repo, node, skip_text=None, extension='.py'):
         self.ui = ui
         self.repo = repo
         self.node = node
         self.skip_text = skip_text
+        self.extension = extension
 
     def skip_file(self, filename, filedata):
-        if not filename.endswith('.py'):
+        if not filename.endswith(self.extension):
             return True
 
         for match in skip_pattern.findall(filedata):
